OC.L10N.register(
    "mail",
    {
    "Mail" : "Pochta",
    "Name" : "Ism...",
    "Password" : "Parol",
    "Save" : "Saqlash",
    "Connect" : "Ulanmoq",
    "Send" : "Yuborish",
    "Move" : "Ko'chiring",
    "Delete" : "O'chir",
    "Choose" : "Tanlang",
    "Settings" : "Sozlamalar",
    "Saving" : "Saqlanmoqda",
    "Cancel" : "Bekor qilish",
    "General" : "Umumiy",
    "Search" : "Qidirmoq",
    "Refresh" : "Yangilash",
    "All" : "Hammasi"
},
"nplurals=1; plural=0;");
